==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-string/xl-react-widget-string.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {
    getModelValue,
    isComponentDisabled,
    resetPristinity,
    getDefaultValue
} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextState,
    computeNextPropsState,
    getValidators
} from '../../services/component-service';
import RU from '../../utils/ramda-utils';

import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {XlReactWidgetStringComponent} from './xl-react-widget-string-component';

export class XlReactWidgetString extends Component {
    static propTypes = {
        addons: PropTypes.oneOfType([
            PropTypes.node,
            PropTypes.arrayOf(PropTypes.node)
        ]),
        inputIconRenderer: PropTypes.func,
        metadata: PropTypes.object,
        model: PropTypes.string,
        onKeyPress: PropTypes.func,
        required: PropTypes.bool,
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {metadata: {}, validators: []};

    state = {};

    componentWillMount() {
        const model = getModelValue(this.props, 'model', '');
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    handleBlur = () => {
        if (!this.state.pristine) {
            this.applyNewValue(this.state.model);
        }
    };

    handleChange = (event) => {
        this.setState({phantomPristinity: false});
        this.applyNewValue(event.target.value);
    };

    handleErase = () => {
        this.applyNewValue('');
    };

    handleKeyPress = (event) => {
        RU.invoke(['onKeyPress'], [event], this.props);
    };

    handleStageModel = () => {
        this.setState({model: '', phantomPristinity: true, stagedModel: this.state.model});
    };

    handleUnstageModel = () => {
        if (this.state.phantomPristinity) {
            this.setState({model: this.state.stagedModel, stagedModel: undefined});
        }
    };

    computeComponentInitialState = (model) => computeInitialState(
        this,
        this.props,
        getValidators(this.props),
        model
    );

    api = {
        applyDefaultModel: () => this.computeComponentInitialState(R.or(getDefaultValue(this.props), '')),
        focus: () => this.inputField.focus(),
        isPristine: () => this.state.pristine,
        markAsDirty: () => {
            this.state.pristine = false; // eslint-disable-line
        },
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    applyNewValue(model) {
        RU.invoke(['metadata', 'onUserInput'], [model], this.props);
        computeNextState(this, this.props, getValidators(this.props), model);
    }

    assignRef = (input) => {
        this.inputField = input;
    };

    render() {
        const {
            addons,
            className,
            inputIconRenderer,
            metadata: {
                autocomplete,
                description,
                label,
                name,
                placeholder,
                required,
                requiredDirection,
                type,
                size
            }
        } = this.props;
        const {message, model, pristine, valid} = this.state;

        const disabled = isComponentDisabled(this.props);

        return <XlReactWidgetStringComponent {...{
            addons,
            assignRef: this.assignRef,
            autocomplete,
            className,
            description,
            disabled,
            inputIconRenderer,
            label,
            message,
            model,
            name,
            onBlur: this.handleBlur,
            onErase: this.handleErase,
            onKeyPress: this.handleKeyPress,
            onModelChange: this.handleChange,
            onStageModel: this.handleStageModel,
            onUnstageModel: this.handleUnstageModel,
            placeholder,
            pristine,
            required,
            requiredDirection,
            size,
            type,
            valid
        }}
        />;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-string/xl-react-widget-string.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import RS from 'ramdasauce';
import debounce from 'debounce';
import {getDefaultValue, getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import {
    computeInitialState,
    computeNextPropsState,
    computeNextState,
    getValidators
} from '../../services/component-service';
import RU from '../../utils/ramda-utils';

import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {XlReactWidgetStringComponent} from './xl-react-widget-string-component';

export const INPUT_DEBOUNCE_TIME = 100;

export class XlReactWidgetString extends Component {
    static propTypes = {
        addons: PropTypes.oneOfType([
            PropTypes.node,
            PropTypes.arrayOf(PropTypes.node)
        ]),
        inputIconRenderer: PropTypes.func,
        metadata: PropTypes.object,
        model: PropTypes.string,
        onKeyPress: PropTypes.func,
        required: PropTypes.bool,
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {metadata: {}, validators: []};

    constructor(props) {
        super(props);

        this.state = {
            canRevealPassword: !props.model,
            revealPassword: false,
            tempModel: ''
        };
        this.debouncedApplyNewValue = debounce(this.applyNewValue, INPUT_DEBOUNCE_TIME);
    }

    componentWillMount() {
        const model = getModelValue(this.props, 'model', '');
        computeInitialState(this, this.props, getValidators(this.props), model);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps));
    }

    componentWillUnmount() {
        RU.invoke('unregister', [], this.props);
    }

    handleBlur = () => {
        if (!this.state.pristine) {
            this.applyNewValue(this.state.model);
        }
    };

    handleChange = (event) => {
        const {value} = event.target;
        this.useTempModel = true;
        if (RS.isNilOrEmpty(value) && !this.state.canRevealPassword) {
            this.setState({canRevealPassword: true, phantomPristinity: false, tempModel: value});
        } else {
            this.setState({phantomPristinity: false, tempModel: value});
        }
        this.debouncedApplyNewValue(value);
    };

    handleErase = () => {
        this.applyNewValue('');
    };

    handleKeyPress = (event) => {
        RU.invoke(['onKeyPress'], [event], this.props);
    };

    handleStageModel = () => {
        this.setState({model: '', phantomPristinity: true, stagedModel: this.state.model});
    };

    handleUnstageModel = () => {
        if (this.state.phantomPristinity) {
            this.setState({model: this.state.stagedModel, stagedModel: undefined});
        }
    };

    handleRevealPassword = () => {
        this.setState({revealPassword: !this.state.revealPassword});
    };

    handleOnPaste = () => {
        this.setState({canRevealPassword: true});
    };

    useTempModel = false;

    computeComponentInitialState = (model) => computeInitialState(
        this,
        this.props,
        getValidators(this.props),
        model
    );

    api = {
        applyDefaultModel: () => this.computeComponentInitialState(R.or(getDefaultValue(this.props), '')),
        focus: () => this.inputField.focus(),
        isPristine: () => this.state.pristine,
        markAsDirty: () => {
            this.state.pristine = false; // eslint-disable-line
        },
        resetPristinity: (config) => {
            this.setState({canRevealPassword: !this.props.model, revealPassword: false});
            resetPristinity(this, this.props, config);
        }
    };

    applyNewValue(model) {
        this.useTempModel = false;
        RU.invoke(['metadata', 'onUserInput'], [model], this.props);
        computeNextState(this, this.props, getValidators(this.props), model);
    }

    assignRef = (input) => {
        this.inputField = input;
    };

    render() {
        const {
            addons,
            className,
            inputIconRenderer,
            metadata: {
                autocomplete,
                description,
                label,
                language,
                name,
                placeholder,
                required,
                requiredDirection,
                type,
                size,
                view
            }
        } = this.props;
        const {
            canRevealPassword,
            message,
            model,
            pristine,
            revealPassword,
            tempModel,
            valid
        } = this.state;

        const disabled = isComponentDisabled(this.props);

        return <XlReactWidgetStringComponent {...{
            addons,
            assignRef: this.assignRef,
            autocomplete,
            canRevealPassword,
            className,
            description,
            disabled,
            inputIconRenderer,
            label,
            language,
            message,
            model: this.useTempModel ? tempModel : model,
            name,
            onBlur: this.handleBlur,
            onErase: this.handleErase,
            onKeyPress: this.handleKeyPress,
            onModelChange: this.handleChange,
            onPaste: this.handleOnPaste,
            onRevealPasswordToggle: this.handleRevealPassword,
            onStageModel: this.handleStageModel,
            onUnstageModel: this.handleUnstageModel,
            placeholder,
            pristine,
            required,
            requiredDirection,
            revealPassword,
            size,
            type,
            valid,
            view
        }}
        />;
    }
}
